Installing peewee — peewee 0.9.8 documentation

### Navigation

- index
- next |
- previous |
- peewee 0.9.8 documentation »

# Installing peewee

    pip install peewee

## Installing with git

You can pip install the git clone:

    pip install -e git+https://github.com/coleifer/peewee.git

If you don’t want to use pip:

    git clone https://github.com/coleifer/peewee.git
    cd peewee
    python setup.py install

You can test your installation by running the test suite.

    python setup.py test

Feel free to check out the Example app which ships with the project.

### Navigation

- index
- next |
- previous |
- peewee 0.9.8 documentation »